/*
 *  
 *  Copyright © 2008 Colomban "Ban" Wendling <ban@herbesfolles.org>
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *  
 */

/*
 * Creation date: Tue Nov 25 14:50:49 2008 +0100
 * Revision date: Tue Nov 25 15:23:30 2008 +0100
 */

/* Notebook tab close button based on gnome-terminal's terminal-window.c code,
 * Copyright (C) 2001 Havoc Pennington
 * Copyright (C) 2002 Red Hat, Inc.
 */


#include "geanyclosetabbutton.h"
#include <glib.h>
#include <glib/gi18n.h>
#include <gtk/gtkbutton.h>
#include <gtk/gtkimage.h>
#include <gtk/gtk.h>


struct _GeanyCloseTabButtonPrivate
{
	GtkWidget* image;
};


static void geany_close_tab_button_class_init	(GeanyCloseTabButtonClass*	klass);
static void geany_close_tab_button_init			(GeanyCloseTabButton*			self);
static void geany_close_tab_button_finalize		(GObject*					object);
static void geany_close_tab_button_style_set	(GtkWidget*					widget,
												 GtkStyle*					previous_style);


G_DEFINE_TYPE(GeanyCloseTabButton, geany_close_tab_button, GTK_TYPE_BUTTON)


static void
geany_close_tab_button_class_init(GeanyCloseTabButtonClass*	klass)
{
	GObjectClass*	object_class = G_OBJECT_CLASS(klass);
	GtkWidgetClass*	widget_class = GTK_WIDGET_CLASS(klass);
	
	object_class->finalize	= geany_close_tab_button_finalize;
	widget_class->style_set	= geany_close_tab_button_style_set;
	
	gtk_rc_parse_string (
		"style \"geany-close-tab-button-style\" {\n"
		"	GtkWidget::focus-padding = 0\n"
		"	GtkWidget::focus-line-width = 0\n"
		"	xthickness = 0\n"
		"	ythickness = 0\n"
		"}\n"
		"widget \"*.geany-close-tab-button\" style \"geany-close-tab-button-style\""
	);
}

static void
geany_close_tab_button_init(GeanyCloseTabButton*	self)
{
	GeanyCloseTabButtonPrivate* priv;
	
	priv = g_new(GeanyCloseTabButtonPrivate, 1);
	self->priv = priv;
	
	gtk_button_set_relief(GTK_BUTTON(self), GTK_RELIEF_NONE);
	gtk_button_set_focus_on_click(GTK_BUTTON(self), FALSE);
	gtk_widget_set_name(GTK_WIDGET(self), "geany-close-tab-button");
#if GTK_CHECK_VERSION(2,12,0)
	gtk_widget_set_tooltip_text(GTK_WIDGET(self), _("Close tab"));
#endif
	
	priv->image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
	gtk_widget_show(priv->image);
	gtk_container_add(GTK_CONTAINER(self), priv->image);
}

static void
geany_close_tab_button_finalize(GObject* object)
{
	GeanyCloseTabButton* self = GEANY_CLOSE_TAB_BUTTON(object);
	
	g_free(self->priv);
	
	G_OBJECT_CLASS(geany_close_tab_button_parent_class)->finalize(object);
}

static void
geany_close_tab_button_style_set(GtkWidget*	widget,
								 GtkStyle*	previous_style)
{
	gint h, w;
	
	gtk_icon_size_lookup_for_settings(gtk_widget_get_settings(widget), GTK_ICON_SIZE_MENU, &w, &h);
	gtk_widget_set_size_request(widget, w + 2, h + 2);
}


GtkWidget*
geany_close_tab_button_new(void)
{
	return GTK_WIDGET(g_object_new(GEANY_TYPE_CLOSE_TAB_BUTTON, NULL));
}
